#!/usr/bin/perl -w 

#==============================================================================
#     (c) Copyright 2006, Hewlett-Packard, all rights reserved.
#
#     PACKAGE      HP OpenView OmniBack II
#     FILE         DPvmware_createsnapshot.pl
#     RCS          $Header: /src/util/VMWareESX/DPvmware_createsnapshot.pl /main/dp60_fix/dp60_patch/1 2008-06-30 11:21:33 bhasing $
#     AUTHOR       Kari Varada Raja Kumar
#
#     DESCRIPTION
#     This script creates snapshot of the virtual machine entered in the DPvmware_config.sh as to put in HOT mode. 
#
#     USAGE: 
#      DPvmware_createsnapshot.pl <path_to_config_file> [<server> <user> <password>]
#
#     If server, user and password are not given, connect to the local server as the current user.
#==============================================================================


use VMware::VmPerl;
use VMware::VmPerl::VM;
use VMware::VmPerl::ConnectParams;
use strict;

# Retrieves a pre-defined constant value.
sub vm_constant {
   my $constant_str = shift;
   return VMware::VmPerl::constant($constant_str, 0);
}

sub TimeStamp
{
        my ($sec,$min,$hour,$mday,$mon,$year) = localtime(time);
        return sprintf "%04d-%02d-%02d %02d:%02d:%02d",
                $year+1900, $mon+1, $mday, $hour, $min, $sec;
}


if (@ARGV < 1) {
   print "Usage $0: <path_to_config_file> [<server> <user> <password>]\n";
   exit -1;
}

# Read in parameters.
my ($cfg_path, $server_name, $user, $passwd) = @ARGV;
my $debugfile=`cat /tmp/vmwaredebug`;
open(DEBUG, ">> $debugfile") or die "cannot open debug file : $!";
print DEBUG TimeStamp()."DPVmware_createsnapshot started\n";

# Use the default server port. Set to some real port number if server listens
# on a non-default port
my $port = undef;

my $connect_params = VMware::VmPerl::ConnectParams::new($server_name,$port,$user,$passwd);

my $vm = VMware::VmPerl::VM::new();
if (!$vm->connect($connect_params, $cfg_path)) {
   my ($error_number, $error_string) = $vm->get_last_error();
   print DEBUG TimeStamp()."Could not connect to vm: Error $error_number: $error_string\n";
   exit -1;
}

my ($err,$errorNumber,$errorString,$data_file)=undef;

#keeping track of the virtual machines for which snapshot has been created.
#These VM are used while removing the snapshots after the backup.

$data_file="/tmp/list_running_vms_to_put_in_hot.tmp";
open(DAT,">>$data_file") || die("Could not open file!");
undef $err;
$err = $vm->has_snapshot();
if (!defined($err))
{
	($errorNumber, $errorString) = $vm->get_last_error();
	print DEBUG TimeStamp()."VM has snapshot error: ", $errorString, "\n";
	close(DAT);
	# return error 
	exit -1;
}
elsif ($err == 1) {
	undef $err;
	$err = $vm->remove_snapshots();
	if (!defined($err))
	{
		($errorNumber, $errorString) = $vm->get_last_error();
		print DEBUG TimeStamp()."VM remove snapshot error: ", $errorString, "\n";
		close(DAT);
		# return error 
		exit -1;
	}
	print DEBUG TimeStamp()."Existing snapshots are removed\n";
}
undef $err;
$err = $vm->create_snapshot("DP_snapshot","snapshot from DP",0,0);
if (!defined($err))
{
	($errorNumber, $errorString) = $vm->get_last_error();
	print DEBUG TimeStamp()."VM create snapshot error: ", $errorString, "\n";
	close(DAT);
	# return error 
	exit -1;
}
print DAT "$cfg_path\n";
close DAT;
close DEBUG;
# Disconnecting from the virtual machine.
undef $vm;
exit 0;
