#!/usr/bin/perl -w 

#==============================================================================
#     (c) Copyright 2006, Hewlett-Packard, all rights reserved.
#
#     PACKAGE      HP OpenView OmniBack II
#     FILE         DPvmware_removesnapshot.pl
#     RCS          $Header: /src/util/VMWareESX/DPvmware_removesnapshot.pl /main/dp60_fix/dp60_patch/1 2008-06-30 11:21:55 bhasing $
#     AUTHOR       Kari Varada Raja Kumar
#
#     DESCRIPTION: 
#     This script removes snapshot of the virtual machine entered in the DPvmware_config.sh after the backup
# 
#==============================================================================

use VMware::VmPerl;
use VMware::VmPerl::VM;
use VMware::VmPerl::ConnectParams;
use strict;

# Retrieves a pre-defined constant value.
sub vm_constant {
   my $constant_str = shift;
   return VMware::VmPerl::constant($constant_str, 0);
}
sub TimeStamp
{
        my ($sec,$min,$hour,$mday,$mon,$year) = localtime(time);
        return sprintf "%04d-%02d-%02d %02d:%02d:%02d",
                $year+1900, $mon+1, $mday, $hour, $min, $sec;
}

# Read in parameters.
my ($cfg_path, $server_name, $user, $passwd) = @ARGV;
my ($err,$errorNumber,$errorString,$data_file)=undef;
my $debugfile=`cat /tmp/vmwaredebug`;
open(DEBUG, ">> $debugfile") or die "Cannot open file";
print DEBUG TimeStamp()."\nDPVmware_removesnapshot started\n";

# Use the default server port. Set to some real port number if server listens
# on a non-default port
my $port = undef;

my $connect_params = VMware::VmPerl::ConnectParams::new($server_name,$port,$user,$passwd);
$data_file="/tmp/list_running_vms_to_put_in_hot.tmp";
open(DAT,"$data_file") || die("Cannot open file");

my @list_of_vms =<DAT>;
foreach my $cfg_path(@list_of_vms) {
	chomp($cfg_path);
	my $vm = VMware::VmPerl::VM::new();
	if (!$vm->connect($connect_params, $cfg_path)) {
  		 my ($error_number, $error_string) = $vm->get_last_error();
  		 die "Could not connect to vm: Error $error_number: $error_string\n";
	}
	$err = $vm->remove_snapshots();
	if (!defined($err)) {
		($errorNumber, $errorString) = $vm->get_last_error();
		print DEBUG TimeStamp()."VM remove snapshot error: ", $errorString, "\n";
		close(DAT);
		exit -1;
	}
	# Destroys the virtual machine object, thus disconnecting from the virtual machine.
	undef $vm;
}
close DAT;
close DEBUG;
exit 0;
