#!/bin/bash

#==============================================================================
#     (c) Copyright 2006, Hewlett-Packard, all rights reserved.
#
#     PACKAGE      HP OpenView OmniBack II
#     FILE         DPvmware_setup.sh
#     RCS          $Header: /src/util/VMWareESX/DPvmware_setup.sh /main/dp60_fix/5 2008-05-13 16:23:06 palos $
#     AUTHOR       Kari Varada Raja Kumar
#
#     DESCRIPTION
#         Do not edit this script manually. 
#         A wrong edit of this file may disrupt the installation.
#         This script is used for the initial configuration.       
#==============================================================================

show_usage () {
	echo "Usage: $0 OPTION"
	echo "OPTIONS  --install   - install the Data Protector VMware Package"
	echo "         --mount     - mounts the vmfs file system for DP purposes"
	echo "         --unmount   - unmounts the vmfs file system"
	echo "         --help      - help for the setup script" 
    exit 1
}

link_files() {

if [ -d "/opt/omni/bin" ]&& [ -s "/opt/omni/lbin/inet" ] ; then
        `ln -sf /opt/omni/bin/DPvmware_preexec.sh   /opt/omni/lbin/DPvmware_preexec.sh` > /dev/null 2>&1
        `ln -sf /opt/omni/bin/DPvmware_postexec.sh  /opt/omni/lbin/DPvmware_postexec.sh` > /dev/null 2>&1
fi

}


mount_vmfs () {
        # if VMFS partition is not mounted on /vmfs we should
        # mount it as it will not be visible under df command
        # if it is not mounted and DP will not be able to see it
        # no need to exit if already mounted.

        if [ `df | grep "/vmfs" | wc -l` = 0 ]; then
			if [ $VERSION = 1 ]; then
			$SCRIPT_DIR/DPvmware_vmfs-mount.sh	
			else
				mount -t vmfs vmfs /vmfs
			fi	
		echo "mounted vmfs on /vmfs"
        else
                echo "VMFS is already mounted on following:"
                mount | grep vmfs
        fi
}

unmount_vmfs () {
        # unmount the vmfs partition(s) mounted on /vmfs
        # need not check if they exist in the vdf output or not
        # if they are not mounted, ESX still knows about them.
        # no need to exit if not mounted.

        if [ `df | grep vmfs | wc -l` -gt 0 ]; then
                echo -n "unmounting VMFS...."
                umount `mount | grep vmfs | awk '/on/ {print $1}'`
                echo "done"
        else
                echo "VMFS is not mounted. Can not unmount..."
        fi
}

#getting the DP version information

if [ -d "/opt/omni/bin" ] && [ -s "/opt/omni/lbin/inet" ] ; then
SCRIPT_DIR=/opt/omni/bin
else
SCRIPT_DIR=/usr/omni/bin
fi

# Getting the version information from ESX server.
VERSION=`vmware -v | grep -i "VMware ESX Server 2" | wc -l`

#main part of script

if [ `id -nu` = "root" ]; then
	if [ $# -ne 1 ]; then
		show_usage
	else
		case "${1}" in
                        "--install")    link_files          
					mount_vmfs
			                echo "Data Protector - VMware package installed."
			                exit 0 ;;
			"--mount")	mount_vmfs
					exit 0 ;;
			"--unmount")	unmount_vmfs
					exit 0 ;;
			"--help")	show_usage
					exit 0 ;;
			*)		echo "Invalid option."
				        echo "use $0 --help for list of options and their usage."
					exit 1;;
		esac
	fi
else
	echo "You must be root to execute this script..."
	exit 1
fi
